@@ -1,8 +1,6 @@
 function.MaxDOR <-
-function(data, marker, status, tag.healthy = 0, direction = c("<", ">"), control = control.cutpoints(), pop.prev, ci.fit = FALSE, conf.level = 0.95){
-	direction <- match.arg(direction)
-	measures.acc <- calculate.accuracy.measures(data, marker, status, tag.healthy, direction, pop.prev, control, ci.fit, conf.level) 
-		
+function(data, marker, status, tag.healthy = 0, direction = c("<", ">"), control = control.cutpoints(), pop.prev, ci.fit = FALSE, conf.level = 0.95, measures.acc = NULL){
+	direction <- match.arg(direction)		
 	TP <- measures.acc$Se[,1]*measures.acc$n$d
 	TP[TP == 0] <- 0.5
 	
