@@ -1,8 +1,6 @@
 function.MaxSpSe <-
-function(data, marker, status, tag.healthy = 0, direction = c("<", ">"), control = control.cutpoints(), pop.prev, ci.fit = FALSE, conf.level = 0.95){
-	direction <- match.arg(direction)
-	measures.acc <- calculate.accuracy.measures(data, marker, status, tag.healthy, direction, pop.prev, control, ci.fit, conf.level)	
-	
+function(data, marker, status, tag.healthy = 0, direction = c("<", ">"), control = control.cutpoints(), pop.prev, ci.fit = FALSE, conf.level = 0.95, measures.acc = NULL){
+	direction <- match.arg(direction)	
 	m <- vector()
 	for(i in 1:length(measures.acc$cutoffs)) {
 		if (measures.acc$Se[i,1] <= measures.acc$Sp[i,1]) {
@@ -11,7 +9,7 @@ function(data, marker, status, tag.healthy = 0, direction = c("<", ">"), control
 			m[i] <- measures.acc$Sp[i,1]
 		}
 	}
-	M <- max(m)   
+	M <- max(m,na.rm=TRUE)   
 
 	optimal.index <- which(round(m,10) == round(M,10))
 	cMaxSpSe <- measures.acc$cutoffs[optimal.index]
