@@ -1,5 +1,5 @@
 function.MinValueSe <-
-function(data, marker, status, tag.healthy = 0, direction = c("<", ">"), control = control.cutpoints(), pop.prev, ci.fit = FALSE, conf.level = 0.95){
+function(data, marker, status, tag.healthy = 0, direction = c("<", ">"), control = control.cutpoints(), pop.prev, ci.fit = FALSE, conf.level = 0.95, measures.acc = NULL){
 	direction <- match.arg(direction)  
 	if (control$valueSe < 0 || control$valueSe > 1) {
 		stop("You have entered an invalid minimum value for Sensitivity. \n The minimum value for Sensitivity must be between 0 and 1.", call. = FALSE)
@@ -9,9 +9,7 @@ function(data, marker, status, tag.healthy = 0, direction = c("<", ">"), control
 	}
 	if (control$valueSe == 1) {
 		warning("You have entered the maximum possible value for Sensitivity. \n Please check this value.", call. = FALSE, immediate. = TRUE) 
-	}
-	measures.acc <- calculate.accuracy.measures(data, marker, status, tag.healthy, direction, pop.prev, control, ci.fit, conf.level)
-		
+	}		
 	index.cutpoints <- which(measures.acc$Se[,1] >= control$valueSe)  
 	if (length(index.cutpoints)== 0) {
 		warning("There is no cutoff that fulfills this condition. Please, enter a new value, if desired.", call. = FALSE, immediate. = TRUE)
@@ -24,11 +22,11 @@ function(data, marker, status, tag.healthy = 0, direction = c("<", ">"), control
 		}
 		if (length(index.cutpoints)!= 1) {					 
 			Spnew <- obtain.optimal.measures(cutpoints, measures.acc)$Sp
-			cutpointsSpnew <- cutpoints[which(round(Spnew[,1],10) == round(max(Spnew[,1]),10))]																														 
+			cutpointsSpnew <- cutpoints[which(round(Spnew[,1],10) == round(max(Spnew[,1],na.rm=TRUE),10))]			
 		 
 			if (length(cutpointsSpnew)> 1) {
 				Senew <- obtain.optimal.measures(cutpointsSpnew, measures.acc)$Se
-				cMinValueSe <- cutpointsSpnew[which(round(Senew[,1],10) == round(max(Senew[,1]),10))]				 		
+				cMinValueSe <- cutpointsSpnew[which(round(Senew[,1],10) == round(max(Senew[,1],na.rm=TRUE),10))]				 		
 			}
 
 			if (length(cutpointsSpnew)== 1)  {
