@@ -1,5 +1,5 @@
 function.MinValueSp <-
-function(data, marker, status, tag.healthy = 0, direction = c("<", ">"), control = control.cutpoints(), pop.prev, ci.fit = FALSE, conf.level = 0.95){
+function(data, marker, status, tag.healthy = 0, direction = c("<", ">"), control = control.cutpoints(), pop.prev, ci.fit = FALSE, conf.level = 0.95, measures.acc = NULL){
 	direction <- match.arg(direction)
 	if (control$valueSp < 0 || control$valueSp > 1) {
 		stop("You have entered an invalid minimum value for Specificity. \n The minimum value for Specificity must be between 0 and 1.", call. = FALSE)		
@@ -10,9 +10,6 @@ function(data, marker, status, tag.healthy = 0, direction = c("<", ">"), control
 	if (control$valueSp == 1) {
 		warning("You have entered the maximum possible value for Specificity. \n Please check this value.", call. = FALSE, immediate. = TRUE)		
 	}
-	
-	measures.acc <- calculate.accuracy.measures(data, marker, status, tag.healthy, direction, pop.prev, control, ci.fit, conf.level)
-
 	index.cutpoints <- which(measures.acc$Sp[,1] >= control$valueSp)
 	if (length(index.cutpoints) == 0)
 	{
@@ -26,11 +23,11 @@ function(data, marker, status, tag.healthy = 0, direction = c("<", ">"), control
 		}
 		if (length(index.cutpoints)!= 1) {
 			Senew <- obtain.optimal.measures(cutpoints, measures.acc)$Se
-			cutpointsSenew <- cutpoints[which(round(Senew[,1],10) == round(max(Senew[,1]),10))] 
+			cutpointsSenew <- cutpoints[which(round(Senew[,1],10) == round(max(Senew[,1],na.rm=TRUE),10))] 
 															   
 			if (length(cutpointsSenew)> 1) {
 				Spnew <- obtain.optimal.measures(cutpointsSenew, measures.acc)$Sp
-				cMinValueSp <- cutpointsSenew[which(round(Spnew[,1],10) == round(max(Spnew[,1]),10))]	
+				cMinValueSp <- cutpointsSenew[which(round(Spnew[,1],10) == round(max(Spnew[,1],na.rm=TRUE),10))]	
 			}	 
 			if (length(cutpointsSenew)== 1) {
 				cMinValueSp <- cutpointsSenew
